You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by lt...@apache.org on 2006/02/20 19:36:51 UTC

svn commit: r379195 - in /maven/maven-1/plugins/trunk/jxr/src: main/org/apache/maven/jxr/ test/org/apache/maven/jxr/

Author: ltheussl
Date: Mon Feb 20 10:36:49 2006
New Revision: 379195

URL: http://svn.apache.org/viewcvs?rev=379195&view=rev
Log:
Fix javadocs, add package.html.

Added:
    maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/package.html   (with props)
    maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/package.html   (with props)
Removed:
    maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/package-info.java
Modified:
    maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/JxrBean.java
    maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/JxrBeanTest.java

Modified: maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/JxrBean.java
URL: http://svn.apache.org/viewcvs/maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/JxrBean.java?rev=379195&r1=379194&r2=379195&view=diff
==============================================================================
--- maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/package.html (added)
+++ maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/package.html Mon Feb 20 10:36:49 2006
@@ -0,0 +1,22 @@
+<!-- 
+/*
+ * Copyright 2006 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+ -->
+ <html>
+ <body>
+    <p>A bean to interact with the maven JXR code.</p>
+ </body>
+ </html>
\ No newline at end of file

Propchange: maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/package.html
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/package.html
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"

Modified: maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/JxrBeanTest.java
URL: http://svn.apache.org/viewcvs/maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/JxrBeanTest.java?rev=379195&r1=379194&r2=379195&view=diff
==============================================================================
--- maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/JxrBeanTest.java (original)
+++ maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/JxrBeanTest.java Mon Feb 20 10:36:49 2006
@@ -1,13 +1,35 @@
 package org.apache.maven.jxr;
 
+/* ====================================================================
+ *   Copyright 2001-2004 The Apache Software Foundation.
+ *
+ *   Licensed under the Apache License, Version 2.0 (the "License");
+ *   you may not use this file except in compliance with the License.
+ *   You may obtain a copy of the License at
+ *
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *   Unless required by applicable law or agreed to in writing, software
+ *   distributed under the License is distributed on an "AS IS" BASIS,
+ *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *   See the License for the specific language governing permissions and
+ *   limitations under the License.
+ * ====================================================================
+ */
+
 import junit.framework.TestCase;
 
+ /** A test class for JxrBean. */
 public class JxrBeanTest
     extends TestCase
 {
 
+    /** A JxrBean. */
     private JxrBean jxrBean;
 
+    /** Setup.
+     * @throws Exception Exception
+     */
     protected void setUp()
         throws Exception
     {
@@ -24,6 +46,9 @@
         jxrBean.setBottom( "copyright" );
     }
 
+    /** testXref.
+     * @throws Exception Exception
+     */
     public void testXref()
         throws Exception
     {

Added: maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/package.html
URL: http://svn.apache.org/viewcvs/maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/package.html?rev=379195&view=auto
==============================================================================
--- maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/package.html (added)
+++ maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/package.html Mon Feb 20 10:36:49 2006
@@ -0,0 +1,22 @@
+<!-- 
+/*
+ * Copyright 2006 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+ -->
+ <html>
+ <body>
+    <p>Test class for JXRBean.</p>
+ </body>
+ </html>
\ No newline at end of file

Propchange: maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/package.html
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: maven/maven-1/plugins/trunk/jxr/src/test/org/apache/maven/jxr/package.html
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"
--- maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/JxrBean.java (original)
+++ maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/JxrBean.java Mon Feb 20 10:36:49 2006
@@ -36,29 +36,37 @@
  */
 public class JxrBean
 {
-    /*
-     * See the doc comments for the corresponding getter/setter methods
-     */
+    /** List of source directories to be cross-referenced. */
     private List sourceDirs;
 
+    /** The destination directory for jxr output. */
     private String destDir;
 
+    /** The locale. */
     private Locale locale;
 
+    /** The inputEncoding. */
     private String inputEncoding;
 
+    /** The outputEncoding. */
     private String outputEncoding;
 
+    /** Used to cross-reference with javadoc pages. */
     private String javadocDir;
 
+    /** Used by DirectoryIndexer. */
     private String windowTitle;
 
+    /** Used by DirectoryIndexer. */
     private String docTitle;
 
+    /** Used by DirectoryIndexer. */
     private String bottom;
 
+    /** Where the navigation templates are located. */
     private String templateDir;
 
+    /** Used for logging. */
     private final Log log = LogFactory.getLog( JxrBean.class );
 
     /**
@@ -71,6 +79,7 @@
 
     /**
      * Starts the cross-referencing and indexing.
+     * @throws JxrException JxrException
      */
     public void xref()
         throws JxrException
@@ -119,7 +128,6 @@
 
     /**
      * Sets a single source directory to be cross-referenced.
-     *
      * @param sourceDir The source directory to be cross-referenced.
      */
     public void setSourceDir( String sourceDir )
@@ -133,7 +141,6 @@
 
     /**
      * Adds a directory to the list of those to be cross-referenced.
-     *
      * @param sourceDir The source directory to be cross-referenced.
      */
     public void addSourceDir( String sourceDir )
@@ -144,44 +151,52 @@
 
     /**
      * DestDir is the directory in which jxr will write its output
      *
      * @param destDir the destination directory for jxr output
      */
-    public void setDestDir( String destDir )
+    public void setDestDir( String newDestDir )
     {
-        this.destDir = destDir;
+        this.destDir = newDestDir;
     }
 
     /**
      * see setDestDir(String)
+     * @return destDir
      */
     public String getDestDir()
     {
         return destDir;
     }
 
+    /**
+     * Returns the locale.
+     * @return the locale.
+     */
     public Locale getLocale()
     {
         return locale;
     }
 
-    public void setLocale( Locale locale )
+    /**
+     *Sets the locale.
+     * @param newLocale the locale.
+     */
+    public void setLocale( Locale newLocale )
     {
-        this.locale = locale;
+        this.locale = newLocale;
     }
 
     /**
      * InputEncoding is the encoding of source files.
      *
      * @param inputEncoding encoding of source files
      */
-    public void setInputEncoding( String inputEncoding )
+    public void setInputEncoding( String newInputEncoding )
     {
-        this.inputEncoding = inputEncoding;
+        this.inputEncoding = newInputEncoding;
     }
 
     /**
      * see setInputEncoding(String)
+     * @return inputEncoding
      */
     public String getInputEncoding()
     {
@@ -191,16 +206,16 @@
 
     /**
      * OutputEncoding is the encoding of output files.
      *
      * @param outputEncoding encoding of output files
      */
-    public void setOutputEncoding( String outputEncoding )
+    public void setOutputEncoding( String newOutputEncoding )
     {
-        this.outputEncoding = outputEncoding;
+        this.outputEncoding = newOutputEncoding;
     }
 
     /**
      * see setOutputEncoding(String)
+     * @return outputEncoding
      */
     public String getOutputEncoding()
     {
@@ -214,15 +229,16 @@
      *
      * If <code>null</code>, no javadoc link will be added.
      *
      * @param javadocDir The root directory containing javadocs
      */
-    public void setJavadocDir( String javadocDir )
+    public void setJavadocDir( String newJavadocDir )
     {
-        this.javadocDir = javadocDir;
+        this.javadocDir = newJavadocDir;
     }
 
     /**
      * see setJavadocDir(String)
+     * @return javadocDir
      */
     public String getJavadocDir()
     {
@@ -231,18 +247,17 @@
 
     /**
      * see DirectoryIndexer
      *
      * @param windowTitle used by DirectoryIndexer
      * @see DirectoryIndexer#setWindowTitle(String) setWindowTitle(String)
      */
-    public void setWindowTitle( String windowTitle )
+    public void setWindowTitle( String newWindowTitle )
     {
-        this.windowTitle = windowTitle;
+        this.windowTitle = newWindowTitle;
     }
 
     /**
      * see DirectoryIndexer
-     *
+     * @return windowTitle
      * @see DirectoryIndexer#setWindowTitle(String) setWindowTitle(String)
      */
     public String getWindowTitle()
@@ -252,18 +267,17 @@
 
     /**
      * see DirectoryIndexer
      *
      * @param docTitle used by DirectoryIndexer
      * @see DirectoryIndexer#setDocTitle(String) setDocTitle(String)
      */
-    public void setDocTitle( String docTitle )
+    public void setDocTitle( String newDocTitle )
     {
-        this.docTitle = docTitle;
+        this.docTitle = newDocTitle;
     }
 
     /**
      * see DirectoryIndexer
-     *
+     * @return docTitle
      * @see DirectoryIndexer#setDocTitle(String) setDocTitle(String)
      */
     public String getDocTitle()
@@ -273,18 +287,17 @@
 
     /**
      * see DirectoryIndexer
      *
      * @param bottom used by DirectoryIndexer
      * @see DirectoryIndexer#setBottom(String) setBottom(String)
      */
-    public void setBottom( String bottom )
+    public void setBottom( String newBottom )
     {
-        this.bottom = bottom;
+        this.bottom = newBottom;
     }
 
     /**
      * see DirectoryIndexer
-     *
+     * @return bottom
      * @see DirectoryIndexer#setBottom(String) setBottom(String)
      */
     public String getBottom()
@@ -294,16 +307,16 @@
 
     /**
      * TemplateDir is where the navigation templates are located
      *
      * @param templateDir the template directory
      */
-    public void setTemplateDir( String templateDir )
+    public void setTemplateDir( String newTemplateDir )
     {
-        this.templateDir = templateDir;
+        this.templateDir = newTemplateDir;
     }
 
     /**
      * see setTemplateDir(String)
+     * @return templateDir
      */
     public String getTemplateDir()
     {
@@ -144,44 +151,52 @@
     /**
      * DestDir is the directory in which jxr will write its output
-     *
-     * @param destDir the destination directory for jxr output
+     * @param newDestDir the destination directory for jxr output
      */
@@ -144,44 +151,52 @@
     /**
      * InputEncoding is the encoding of source files.
-     *
-     * @param inputEncoding encoding of source files
+     * @param newInputEncoding encoding of source files
      */
@@ -191,16 +206,16 @@
     /**
      * OutputEncoding is the encoding of output files.
-     *
-     * @param outputEncoding encoding of output files
+     * @param newOutputEncoding encoding of output files
      */
@@ -214,15 +229,16 @@
      * If <code>null</code>, no javadoc link will be added.
      *
-     * @param javadocDir The root directory containing javadocs
+     * @param newJavadocDir The root directory containing javadocs
      */
@@ -231,18 +247,17 @@
     /**
      * see DirectoryIndexer
-     *
-     * @param windowTitle used by DirectoryIndexer
+     * @param newWindowTitle used by DirectoryIndexer
      * @see DirectoryIndexer#setWindowTitle(String) setWindowTitle(String)
      */
@@ -252,18 +267,17 @@
     /**
      * see DirectoryIndexer
-     *
-     * @param docTitle used by DirectoryIndexer
+     * @param newDocTitle used by DirectoryIndexer
      * @see DirectoryIndexer#setDocTitle(String) setDocTitle(String)
      */
@@ -273,18 +287,17 @@
     /**
      * see DirectoryIndexer
-     *
-     * @param bottom used by DirectoryIndexer
+     * @param newBottom used by DirectoryIndexer
      * @see DirectoryIndexer#setBottom(String) setBottom(String)
      */
@@ -294,16 +307,16 @@
     /**
      * TemplateDir is where the navigation templates are located
-     *
-     * @param templateDir the template directory
+     * @param newTemplateDir the template directory
      */

Added: maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/package.html
URL: http://svn.apache.org/viewcvs/maven/maven-1/plugins/trunk/jxr/src/main/org/apache/maven/jxr/package.html?rev=379195&view=auto
==============================================================================